@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _DateParser.py 8359 2007-04-06 04:34:48Z dallingham $
+# $Id: _DateParser.py 10855 2008-07-14 12:17:40Z bmcage $
 
 """
 Date parsing class. Serves as the base class for any localized
@@ -27,9 +27,6 @@ date parsing class. The default, base class provides parsing for
 English.
 """
 
-__author__ = "Donald N. Allingham"
-__version__ = "$Revision: 8359 $"
-
 #-------------------------------------------------------------------------
 #
 # Python modules
@@ -51,7 +48,7 @@ log = logging.getLogger(".DateParser")
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from RelLib import Date, DateError
+from gen.lib import Date, DateError
 import GrampsLocale
 
 #-------------------------------------------------------------------------
@@ -85,14 +82,14 @@ def gregorian_valid(date_tuple):
 #-------------------------------------------------------------------------
 class DateParser:
     """
-    Converts a text string into a Date object. If the date cannot be
+    Convert a text string into a Date object. If the date cannot be
     converted, the text string is assigned.
     """
 
     _fmt_parse = re.compile(".*%(\S).*%(\S).*%(\S).*")
 
     # RFC-2822 only uses capitalized English abbreviated names, no locales.
-    _rfc_days = ('Sun','Mon','Tue','Wed','Thu','Fri','Sat')
+    _rfc_days = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat')
     _rfc_mons_to_int = {
         'Jan' : 1,  'Feb' : 2,  'Mar' : 3,  'Apr' : 4,
         'May' : 5,  'Jun' : 6,  'Jul' : 7,  'Aug' : 8,
@@ -200,21 +197,23 @@ class DateParser:
         fmt = GrampsLocale.tformat
         match = self._fmt_parse.match(fmt.lower())
         if match:
-            self.dmy = (match.groups() == ('d','m','y'))
-            self.ymd = (match.groups() == ('y','m','d'))
+            self.dmy = (match.groups() == ('d', 'm', 'y') or \
+                       match.groups() == ('d', 'b', 'y'))
+            self.ymd = (match.groups() == ('y', 'm', 'd') or \
+                       match.groups() == ('y', 'b', 'd'))
         else:
             self.dmy = True
             self.ymd = False
 
     def re_longest_first(self, keys):
-	"""
-	returns a string for a RE group which contains the given keys
+        """
+        returns a string for a RE group which contains the given keys
         sorted so that longest keys match first.  Any '.' characters
-	are quoted.
-	"""
-	keys.sort(lambda x, y: cmp(len(y), len(x)))
-	return '(' + '|'.join([key.replace('.','\.') for key in keys]) + ')'
-	
+        are quoted.
+        """
+        keys.sort(lambda x, y: cmp(len(y), len(x)))
+        return '(' + '|'.join([key.replace('.', '\.') for key in keys]) + ')'
+
     def init_strings(self):
         """
         This method compiles regular expression strings for matching dates.
@@ -248,47 +247,47 @@ class DateParser:
         self._bce_re   = re.compile("(.*)\s+%s( ?.*)" % self._bce_str)
 
         self._cal      = re.compile("(.*)\s+\(%s\)( ?.*)" % self._cal_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._qual     = re.compile("(.* ?)%s\s+(.+)" % self._qual_str,
-                           re.IGNORECASE)
-
+                                    re.IGNORECASE)
+        
         self._span     = re.compile("(from)\s+(?P<start>.+)\s+to\s+(?P<stop>.+)",
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._range    = re.compile("(bet|bet.|between)\s+(?P<start>.+)\s+and\s+(?P<stop>.+)",
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._modifier = re.compile('%s\s+(.*)' % self._mod_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._modifier_after = re.compile('(.*)\s+%s' % self._mod_after_str,
-                           re.IGNORECASE)
-        self._abt2     = re.compile('<(.*)>',re.IGNORECASE)
-        self._text     = re.compile('%s\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._mon_str,
-                           re.IGNORECASE)
-        self._text2    = re.compile('(\d+)?\s+?%s\s*((\d+)(/\d+)?)?\s*$' % self._mon_str,
-                           re.IGNORECASE)
+                                          re.IGNORECASE)
+        self._abt2     = re.compile('<(.*)>', re.IGNORECASE)
+        self._text     = re.compile('%s\.?\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._mon_str,
+                                    re.IGNORECASE)
+        self._text2    = re.compile('(\d+)?\s+?%s\.?\s*((\d+)(/\d+)?)?\s*$' % self._mon_str,
+                                    re.IGNORECASE)
         self._jtext    = re.compile('%s\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._jmon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._jtext2   = re.compile('(\d+)?\s+?%s\s*((\d+)(/\d+)?)?\s*$' % self._jmon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._ftext    = re.compile('%s\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._fmon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._ftext2   = re.compile('(\d+)?\s+?%s\s*((\d+)(/\d+)?)?\s*$' % self._fmon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._ptext    = re.compile('%s\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._pmon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._ptext2   = re.compile('(\d+)?\s+?%s\s*((\d+)(/\d+)?)?\s*$' % self._pmon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._itext    = re.compile('%s\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._imon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._itext2   = re.compile('(\d+)?\s+?%s\s*((\d+)(/\d+)?)?\s*$' % self._imon_str,
-                           re.IGNORECASE)
+                                    re.IGNORECASE)
         self._numeric  = re.compile("((\d+)[/\.]\s*)?((\d+)[/\.]\s*)?(\d+)\s*$")
         self._iso      = re.compile("(\d+)(/(\d+))?-(\d+)-(\d+)\s*$")
         self._rfc      = re.compile("(%s,)?\s+(\d|\d\d)\s+%s\s+(\d+)\s+\d\d:\d\d(:\d\d)?\s+(\+|-)\d\d\d\d" 
-                        % (self._rfc_day_str,self._rfc_mon_str))
+                                    % (self._rfc_day_str, self._rfc_mon_str))
 
-    def _get_int(self,val):
+    def _get_int(self, val):
         """
-        Converts the string to an integer if the value is not None. If the
+        Convert the string to an integer if the value is not None. If the
         value is None, a zero is returned
         """
         if val == None:
@@ -363,7 +362,7 @@ class DateParser:
     
     def _parse_subdate(self, text, subparser=None):
         """
-        Converts only the date portion of a date.
+        Convert only the date portion of a date.
         """
         if subparser == None:
             subparser = self._parse_greg_julian
@@ -386,9 +385,9 @@ class DateParser:
             if check and not check((d, m, y)):
                 return Date.EMPTY
             if groups[2]:
-                return (d, m, y,True)
+                return (d, m, y, True)
             else:
-                return (d, m, y,False)
+                return (d, m, y, False)
 
         match = self._rfc.match(text)
         if match:
@@ -422,8 +421,8 @@ class DateParser:
                 else:
                     m = self._get_int(groups[1])
                     d = self._get_int(groups[3])
-            value = (d,m,y,False)
-            if check and not check((d,m,y)):
+            value = (d, m, y, False)
+            if check and not check((d, m, y)):
                 value = Date.EMPTY
             return value
         
@@ -439,7 +438,7 @@ class DateParser:
         if match:
             cal = self.calendar_to_int[match.group(2).lower()]
             text = match.group(1) + match.group(3)
-        return (text,cal)
+        return (text, cal)
 
     def match_quality(self, text, qual):
         """
@@ -451,7 +450,7 @@ class DateParser:
         if match:
             qual = self.quality_to_int[match.group(2).lower()]
             text = match.group(1) + match.group(3)
-        return (text,qual)
+        return (text, qual)
 
     def match_span(self, text, cal, qual, date):
         """
@@ -462,12 +461,12 @@ class DateParser:
         match = self._span.match(text)
         if match:
             text_parser = self.parser[cal]
-            (text1,bc1) = self.match_bce(match.group('start'))
-            start = self._parse_subdate(text1,text_parser)
+            (text1, bc1) = self.match_bce(match.group('start'))
+            start = self._parse_subdate(text1, text_parser)
             if bc1:
                 start = self.invert_year(start)
 
-            (text2,bc2) = self.match_bce(match.group('stop'))
+            (text2, bc2) = self.match_bce(match.group('stop'))
             stop = self._parse_subdate(text2, text_parser)
             if bc2:
                 stop = self.invert_year(stop)
@@ -485,12 +484,12 @@ class DateParser:
         match = self._range.match(text)
         if match:
             text_parser = self.parser[cal]
-            (text1,bc1) = self.match_bce(match.group('start'))
+            (text1, bc1) = self.match_bce(match.group('start'))
             start = self._parse_subdate(text1, text_parser)
             if bc1:
                 start = self.invert_year(start)
 
-            (text2,bc2) = self.match_bce(match.group('stop'))
+            (text2, bc2) = self.match_bce(match.group('stop'))
             stop = self._parse_subdate(text2, text_parser)
             if bc2:
                 stop = self.invert_year(stop)
@@ -508,7 +507,7 @@ class DateParser:
         match = self._bce_re.match(text)
         bc = False
         if match:
-	    # bce is in the match.group(2)
+        # bce is in the match.group(2)
             try:
                 text = match.group(1) + match.group(3)
             except:
@@ -578,7 +577,7 @@ class DateParser:
         if self.match_range(text, cal, qual, date):
             return
 
-        (text,bc) = self.match_bce(text)
+        (text, bc) = self.match_bce(text)
         if self.match_modifier(text, cal, qual, bc, date):
             return
 
@@ -596,8 +595,12 @@ class DateParser:
         else:
             date.set(qual, Date.MOD_NONE, cal, subdate)
 
+        if date.get_slash():
+            date.set_calendar(Date.CAL_JULIAN)
+            date.set_year(date.get_year() + 1) # year++ and forces recalc
+
     def invert_year(self, subdate):
-        return (subdate[0] ,subdate[1], -subdate[2], subdate[3])
+        return (subdate[0], subdate[1], -subdate[2], subdate[3])
     
     def parse(self, text):
         """
