@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_fr.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _Date_fr.py 11298 2008-11-13 08:42:05Z ldnp $
 
 """
 French-specific classes for parsing and displaying dates.
@@ -322,5 +322,5 @@ class DateDisplayFR(DateDisplay):
 #
 #-------------------------------------------------------------------------
 register_datehandler(
-    ('fr_FR', 'fr', 'french', 'fr_CA', 'fr_BE', 'fr_CH'), 
+    ('fr_FR', 'fr', 'french', 'French', 'fr_CA', 'fr_BE', 'fr_CH'), 
     DateParserFR, DateDisplayFR)
