@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: base.py 10235 2008-03-09 17:57:34Z bmcage $
+# $Id: base.py 11328 2008-11-21 14:45:14Z ldnp $
 
 """
 Base class for the GRAMPS databases. All database interfaces should inherit
@@ -1857,9 +1857,7 @@ class GrampsDbBase(Callback):
         raise NotImplementedError
 
     def sort_surname_list(self):
-        vals = [(locale.strxfrm(item), item) for item in self.surname_list]
-        vals.sort()
-        self.surname_list = [item[1] for item in vals]
+        self.surname_list.sort(locale.strcoll)
 
     def add_to_surname_list(self, person, batch_transaction):
         if batch_transaction:
