@@ -4,6 +4,7 @@
 # Copyright (C) 2000-2002 Bruce J. DeGrasse
 # Copyright (C) 2000-2007 Donald N. Allingham
 # Copyright (C) 2007-2008 Brian G. Matherly
+# Copyright (C) 2008      James Friedmann <jfriedmannj@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetAncestralReport.py 10162 2008-03-02 19:20:55Z ldnp $
+# $Id: DetAncestralReport.py 11311 2008-11-18 02:20:42Z pez4brian $
 
 """Reports/Text Reports/Detailed Ancestral Report"""
 
@@ -234,8 +235,8 @@ class DetAncestorReport(Report):
         if not self.verbose:
             self.write_parents(person, first)
 
-        text = ReportUtils.born_str(self.database,person,first,self.verbose,
-                                    self.EMPTY_DATE,self.EMPTY_PLACE)
+        text = ReportUtils.born_str(self.database, person, first, self.verbose,
+                                    self.EMPTY_DATE, self.EMPTY_PLACE)
         if text:
             birth_ref = person.get_birth_ref()
             if birth_ref:
@@ -245,9 +246,14 @@ class DetAncestorReport(Report):
             self.doc.write_text(text)
             first = 0
 
+        text = ReportUtils.baptised_str(self.database, person, first, self.verbose, 
+                                        self.endnotes, self.EMPTY_DATE, self.EMPTY_PLACE)
+        if text:
+            self.doc.write_text(text)
+
         age,units = self.calc_age(person)
-        text = ReportUtils.died_str(self.database,person,first,self.verbose,
-                                    self.EMPTY_DATE,self.EMPTY_PLACE,age,units)
+        text = ReportUtils.died_str(self.database, person, first, self.verbose,
+                                    self.EMPTY_DATE, self.EMPTY_PLACE, age, units)
         if text:
             death_ref = person.get_death_ref()
             if death_ref:
@@ -257,8 +263,8 @@ class DetAncestorReport(Report):
             self.doc.write_text(text)
             first = 0
 
-        text = ReportUtils.buried_str(self.database,person,first,
-                                      self.EMPTY_DATE,self.EMPTY_PLACE)
+        text = ReportUtils.buried_str(self.database, person, first, self.verbose, 
+                                        self.endnotes, self.EMPTY_DATE, self.EMPTY_PLACE)
         if text:
             self.doc.write_text(text)
 
@@ -560,28 +566,24 @@ class DetAncestorReport(Report):
 
     def write_mate(self, mate):
         """Output birth, death, parentage, marriage and notes information """
-
+        ind = None
+        has_info = False
+        
         for family_handle in mate.get_family_handle_list():
             family = self.database.get_family_from_handle(family_handle)
-            person_name = ""
             ind_handle = None
-            has_info = False
-            person_key = ""
             if mate.get_gender() == gen.lib.Person.MALE:
                 ind_handle = family.get_mother_handle()
             else:
                 ind_handle = family.get_father_handle()
             if ind_handle:
                 ind = self.database.get_person_from_handle(ind_handle)
-                person_name = _nd.display(ind)
-                person_mark = ReportUtils.get_person_mark(self.database,ind)
-                firstName = ReportUtils.common_name(ind,self.usecall)
-
                 for event_ref in ind.get_primary_event_ref_list():
                     event = self.database.get_event_from_handle(event_ref.ref)
                     if event:
                         etype = event.get_type()
-                        if etype == gen.lib.EventType.BURIAL or \
+                        if etype == gen.lib.EventType.BAPTISM or \
+                           etype == gen.lib.EventType.BURIAL or \
                            etype == gen.lib.EventType.BIRTH  or \
                            etype == gen.lib.EventType.DEATH     :
                             has_info = True
@@ -592,44 +594,66 @@ class DetAncestorReport(Report):
                         f = self.database.get_family_from_handle(family_handle)
                         if f.get_mother_handle() or f.get_father_handle():
                             has_info = True
-            else:
-                firstName = 0
+                            break
 
-            print_name = ReportUtils.common_name(ind, self.usecall)
-            
-            if person_name and has_info:
+            if has_info:
                 self.doc.start_paragraph("DAR-Entry")
 
-                self.doc.write_text(person_name,person_key)
-                #self.doc.write_text(". ")
+                plist = ind.get_media_list()
+                
+                if self.addimages and len(plist) > 0:
+                    photo = plist[0]
+                    ReportUtils.insert_image(self.database, self.doc, photo)
+        
+                name = _nd.display_formal(ind)
+                mark = ReportUtils.get_person_mark(self.database, ind)
+        
+                self.doc.write_text(name, mark)
+                if name[-1:] == '.':
+                    self.doc.write_text("%s " % self.endnotes(ind))
+                else:
+                    self.doc.write_text("%s. " % self.endnotes(ind))
+
+                first_name = ReportUtils.common_name(ind, self.usecall)
+                print_name = first_name
 
                 text = ReportUtils.born_str(self.database, ind, print_name, 
                             self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE)
                 if text:
                     self.doc.write_text(text)
-                    print_name = 0;
+                    print_name = 0
+
+                text = ReportUtils.baptised_str(self.database, ind, print_name, 
+                            self.verbose, self.endnotes, self.EMPTY_DATE, 
+                            self.EMPTY_PLACE)
 
-                age,units = self.calc_age(ind)
-                text = ReportUtils.died_str(self.database,ind,print_name, 
-                           self.verbose, self.EMPTY_DATE,self.EMPTY_PLACE,
-                           age,units)
                 if text:
                     self.doc.write_text(text)
-                    print_name = 0;
+                    print_name = 0
+
+                age, units = self.calc_age(ind)
+                text = ReportUtils.died_str(self.database, ind, print_name, 
+                           self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE,
+                           age, units)
+                if text:
+                    self.doc.write_text(text)
+                    print_name = 0
+                
+                text = ReportUtils.buried_str(self.database, ind, print_name,
+                        self.verbose, self.endnotes, self.EMPTY_DATE, 
+                        self.EMPTY_PLACE)
                 
-                text = ReportUtils.buried_str(self.database,ind,print_name,
-                        self.EMPTY_DATE,self.EMPTY_PLACE)
                 if text:
                     self.doc.write_text(text)
-                    print_name = 0;
+                    print_name = 0
 
                 if print_name == 0:
-                    print_name = firstName
+                    print_name = first_name
                 self.write_parents(ind, print_name)
 
                 self.doc.end_paragraph()
 
-            if person_name and mate.get_gender()==gen.lib.Person.MALE:
+            if has_info and mate.get_gender() == gen.lib.Person.MALE:
                 if self.listchildren:
                     self.write_children(family)
                 if self.inc_events:
