@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: MarkerReport.py 10152 2008-03-01 22:47:48Z pez4brian $
+# $Id: MarkerReport.py 11202 2008-10-27 08:32:05Z romjerome $
 
 """Reports/Text Reports/Marker Report"""
 
@@ -525,5 +525,6 @@ register_report(
     status = _("Stable"),
     description = _("Produces a list of people with a specified marker"),
     author_name = "Brian G. Matherly",
-    author_email = "brian@gramps-project.org"
+    author_email = "brian@gramps-project.org",
+    require_active = False
     )
